*******************************************************************************************************
*******************Setup quarterly HOUR INDEX for ALL countries for post-covid analysis ***************
*******************************************************************************************************
*******************Setup quarterly Employment for ALL countries for post-covid analysis ***************
*******************************************************************************************************
*******************Setup quarterly GDP for ALL countries for post-covid analysis **********************
clear all

*Set Directory
adopath + "...\x12a" // Place seasonal adjustment files provided by Census Bureau and following instructions below. 
gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"
gl output2   = "...\output2"

cd "${output2}/"

****************************************************QUARTERLY HOUR INDEX*******************************************************
******************************************************************************************************************************
clear all
numlist "1/3"
local mylist "`r(numlist)'"
di "`mylist'"
foreach m of local mylist{ 
import excel "${rawdata}\hour_q3.xls", sheet("Data`m'") cellrange(A12:BH46) firstrow allstring //new revised data
label variable GEOTIME "country"
foreach y of varlist _all{
   local x : variable label `y'
   rename `y' y`x'
}
rename ycountry country
foreach y of varlist _all {
   replace `y'="." if `y'==":"
  
}
reshape long y, i(country) j(date,string) 
rename y h_index
destring h_index, replace

gen year=.
replace year= real(substr(date, -6, 4)) 
gen q=.
replace q= real(substr(date, -1,1 )) 


gen yq = yq(year, q)
format yq %tq
keep country year q yq h_index

keep country year yq q h_index
gen sex=`m'

tempfile d`m'
save `d`m''
clear
}
 
use `d1.dta'
numlist "2/3"
local mylist "`r(numlist)'"
di "`mylist'"
foreach m of local mylist{
            append using `d`m'.dta'
 }
 
 
gen sex_="."
replace sex_="tot" if sex==1 
replace sex_="male" if sex==2 
replace sex_="female" if sex==3

drop sex
rename sex_ sex

gen all_index=.
replace all_index=h_index if sex=="tot" 
gen male_index=.
replace male_index=h_index if sex=="male" 
gen female_index=.
replace female_index=h_index if sex=="female"

collapse all_index male_index female_index year q, by(yq country) 
replace country="Germany" if country=="Germany (until 1990 former territory of the FRG)"
replace country="UK" if country=="United Kingdom"

tempfile hour
save `hour'


**********************************QUARTERLY EMPLOYMENT*************************************************************************
*******************************************************************************************************************************
clear all
numlist "1/3"
local mylist "`r(numlist)'"
di "`mylist'"
foreach m of local mylist{
import excel "${rawdata}\emp_q3.xls", sheet("Data`m'") cellrange(A13:DX49) firstrow allstring //quarterly new revised data
label variable GEOTIME "country"
foreach y of varlist _all{
   local x : variable label `y'
   rename `y' y`x'
}
rename ycountry country
foreach y of varlist _all {
   replace `y'="." if `y'==":"
  
}
reshape long y, i(country) j(date,string) 
rename y employed
destring employed, replace
***Quarterly data
gen year=.
replace year= real(substr(date, -6, 4)) 
gen q=.
replace q= real(substr(date, -1,1 )) 


gen yq = yq(year, q)
format yq %tq
keep country year q yq employed
gen sex=`m'

tempfile d`m'
save `d`m''
clear
}
 
use `d1.dta'
numlist "2/3"
local mylist "`r(numlist)'"
di "`mylist'"
foreach m of local mylist{
            append using `d`m'.dta'
 }
 
 
gen sex_="."
replace sex_="tot" if sex==1 
replace sex_="male" if sex==2 
replace sex_="female" if sex==3

drop sex
rename sex_ sex


gen all_emp=.
replace all_emp=employed if sex=="tot" 
gen male_emp=.
replace male_emp=employed if sex=="male" 
gen female_emp=.
replace female_emp=employed if sex=="female" 


collapse all_emp male_emp female_emp , by(year q yq country) 
replace country="Germany" if country=="Germany (until 1990 former territory of the FRG)"
replace country="UK" if country=="United Kingdom"

tempfile emp
save `emp'

******************************Real unadjusted GDP******************************************************************************
*******************************************************************************************************************************
******************************Does seasonal adjustment for 2006-2020q3*********************************************************
clear all
import excel "${rawdata}\gdp_quarter.xls", sheet("Data") cellrange(A11:GB50) firstrow
label variable GEOTIME country
foreach y of varlist _all{
   local x : variable label `y'
   rename `y' y`x'
}
rename ycountry country
foreach y of varlist _all {
   tostring `y', replace
  
}
foreach y of varlist _all {
   replace `y'="." if `y'==":"
  
}
reshape long y, i(country) j(date,string) 
rename y gdp
destring gdp, replace

gen year=.
replace year= real(substr(date, -6, 4)) 
gen q=.
replace q= real(substr(date, -1,1 )) 

gen yq = yq(year, q)
format yq %tq
keep if year>=2006

sort country year q

drop if country=="Bulgaria" | country=="Croatia" | country=="Cyprus" | country=="Euro area - 19 countries  (from 2015)" | country=="European Union - 15 countries (1995-2004)" | country=="European Union - 27 countries (from 2020)" | country=="European Union - 28 countries (2013-2020)" | country=="Malta" | country=="Montenegro" | country=="North Macedonia" | country=="Serbia"

replace country="Germany" if country=="Germany (until 1990 former territory of the FRG)"
replace country="UK" if country=="United Kingdom"

local countrylist " Austria   Belgium  Czechia Denmark  Estonia Finland France Germany Greece Hungary Iceland Ireland Italy  Latvia  Lithuania Luxembourg   Netherlands  Norway Poland  Portugal  Romania  Slovakia  Slovenia  Spain  Sweden   Switzerland UK "

encode country, gen(c)
tsset c yq

tempfile gdp
save `gdp'

cd "${output2}"

****GDP SA**********
*########This code does seasonal adjustment using the program X-13ARIMA-SEATS by Census Bureau: https://www.census.gov/srd/www/x13as/
*We use instructions by Ernie Tedeschi: https://medium.com/@ernietedeschi/how-to-get-x-13arima-seats-working-in-stata-for-windows-9e2e03b7e9c6
foreach c of local countrylist{
use `gdp.dta'
keep if country=="`c'"
sax12 gdp, satype(single) dtafile(gdp)  
sax12im "gdp.out", ext(d11)
gen gdp_sa=gdp_d11 
tempfile `c'
save ``c''
clear all
}

foreach c of local countrylist{
append using ``c'.dta'
}

keep gdp_sa country year q yq

tempfile gdp_sa
save `gdp_sa'

******************************Real adjusted GDP for Canada and US******************************************************************************
*******************************************************************************************************************************
clear all
import excel "${rawdata}\US_gdp.xls", sheet("FRED Graph") cellrange(A11:B306) firstrow clear
gen year=year(observation_date)
gen q=quarter(observation_date)
gen yq=yq(year,q)
rename GDPC1 gdp_sa //billions
keep if year>=1998 // should not compare the level of gdp's across Europe and US and Canada because base year and currency is different
*We are only interested in the change in the pandemic
drop observation_date
gen country="US"
format yq %tq
tsset yq
tempfile us_g
save `us_g'

clear all
import excel "${rawdata}\Canada_gdp.xls", sheet("FRED Graph") cellrange(A11:B250) firstrow
gen year=year(observation_date)
gen q=quarter(observation_date)
gen yq=yq(year,q)
format yq %tq
tsset yq
rename NAEXKP01CAQ189S gdp_sa
keep if year>=1998 // should not compare the level of gdp's across Europe and US and Canada because base year and currency is different
*We are only interested in the change in the pandemic
drop observation_date
gen country="Canada"
tsset yq
tempfile canada_g
save `canada_g'

append using `us_g.dta'
append using `gdp_sa.dta'

save "${procdata}/gdp_sa_quarter.dta", replace

******************************Real adjusted GDP for PPP US dolars OECD reference year******************************************************************************
*******************************************************************************************************************************
clear all
import excel "${rawdata}\gdppercap2.xlsx", sheet("OECD.Stat export") cellrange(A6:DC36) firstrow

drop B C
rename Period country
drop if country=="Country"
foreach y of varlist _all {
   tostring `y', replace
}

foreach y of varlist _all {
   replace `y'="." if `y'==".."
   destring `y', replace
}

reshape long Q, i(country) j(date,string) 
rename Q gdppercap

gen year=.
replace year= real(substr(date, -4, 4)) 
gen q=.
replace q= real(substr(date, -5,1 )) 

gen yq = yq(year, q)
format yq %tq
replace country="Czechia" if country=="Czech Republic"
replace country="Slovakia" if country=="Slovak Republic"
replace country="UK" if country=="United Kingdom"
replace country="US" if country=="United States"

drop date

tempfile  percap
save `percap'

********************************************************************************
************Merging hour-employment-gdp quarterly data for post covid analysis

clear all
use "${procdata}/Canada_quarter_adjusted.dta" //hours estimates from the microdata to build hours index similar to Europe
append using "${procdata}/US_quarter_adjusted.dta" //hours estimates from the microdata to build hours index similar to Europe
merge 1:1 country yq using "${procdata}/ilostat_US_Canada_emp.dta" //brings 20-64 total employment numbers so the rates are useless at the post-Covid period: the main aim is to build a similar hours index (total hours=average hours on the intensive margin X total employment)
keep hours_int hours_int_male hours_int_female female_emp male_emp all_emp country yq q year
tempfile US_Can
save `US_Can'

clear all
use `hour.dta'
merge 1:1 yq country using `emp.dta'
drop _merge
append using `US_Can.dta'

merge 1:1 yq country using  "${procdata}/gdp_sa_quarter.dta"
drop _merge

merge 1:1 yq country using `percap.dta'
drop _merge

keep if country=="Austria" | country=="Belgium" |country=="Czechia" |country=="Denmark" |country=="Estonia" |country=="Finland" |country=="France" |country=="Germany" |country=="Greece" |country=="Hungary" |country=="Iceland" |country=="Ireland" |country=="Italy" |country=="Latvia" |country=="Lithuania" |country=="Luxembourg" |country=="Netherlands" |country=="Norway" |country=="Poland" |country=="Portugal" |country=="Romania" |country=="Slovakia" |country=="Slovenia" |country=="Spain" |country=="Sweden" |country=="Switzerland" | country=="UK" | country=="US" | country=="Canada"

keep if year>=1995


*##########################################***US and CANADA***#######################################################
*******Adjust US and Canada for the hour index as total hours worked: so multiply average hours (intensive margin only) with total employment in numbers
*The purpose of this coding is to build a comparable hours index for Canada and US to the Eurostat Hours index
gen Tot_hour=hours_int*all_emp  //hours_int is the average hours on the intensive margin calculated in CPS and CLFS. All_emp is the total employment taken from Ilostat
gen Tot_hour_m=hours_int_male*male_emp
gen Tot_hour_f=hours_int_female*female_emp
bysort country:egen m2006=mean(Tot_hour) if year==2006
bysort country:egen m2006m=mean(Tot_hour_m) if year==2006
bysort country:egen m2006f=mean(Tot_hour_f) if year==2006
bysort country:egen M2006=mean(m2006) //calculating the mean hours index in 2006, to scale it to 100
bysort country:egen M2006m=mean(m2006m)
bysort country:egen M2006f=mean(m2006f) 
replace all_index=Tot_hour*100/M2006 if country=="US" | country=="Canada" //building hours index, where 2006 is 100. 
replace male_index=Tot_hour_m*100/M2006m if country=="US" | country=="Canada"
replace female_index=Tot_hour_f*100/M2006f if country=="US" | country=="Canada"

*##########################################***GERMANY***############################################################
*To fill out Germany data in the pandemic, we use several sources. IAB volume of work, Mannheim Corona Study and Eurostat
*To be compatible with other countries, we stick on Eurostat hours index for pre-pandemic period. But Germany does not publish pandemic output. To understand, the change in overall hours worked, we use IAB data, as it is reliable and representative source. However, IAB does not provide the gender breakdown. We calculate gender differences from MCS microdata and implement it. However, when doing it, we scale the overall change in MCS to be the same as in IAB, because the hours worked definition is different in MCS and we want to match the overall change and only imput the gender difference within MCS. 

****First enter calculated average hours per person from MCS before and after the pandemic.

gen  hours_int_ext_female=32.466297 if country=="Germany" & year==2018 & q==3 //Mannheim Corona
gen hours_int_ext_male=41.034405 if country=="Germany" & year==2018 & q==3 //Mannheim Corona
gen hours_int_ext=36.740864 if country=="Germany" & year==2018 & q==3 //Mannheim Corona

replace hours_int_ext_female=23.472837 if country=="Germany" & year==2020 & q==2 //Mannheim Corona
replace hours_int_ext_male=31.911333 if country=="Germany" & year==2020 & q==2 //Mannheim Corona
replace hours_int_ext=27.660955 if country=="Germany" & year==2020 & q==2 //Mannheim Corona

***Find what would the "hours index" for everyone, male and female be if we assume MCS to be representative. Note that all_index male_index and female_index are our main variables from Eurostat. We would like to scale it for the period where we have both Eurostat and MCS which is 2018,q3.
gen scale_m=hours_int_ext_male/male_index if country=="Germany" & year==2018 & q==3 //
bysort country: egen sc_m_germany=mean(scale_m)
gen scale_f=hours_int_ext_female/female_index if country=="Germany" & year==2018 & q==3
bysort country: egen sc_f_germany=mean(scale_f)
gen scale_t=hours_int_ext/all_index if country=="Germany" & year==2018 & q==3
bysort country: egen sc_t_germany=mean(scale_t)

****This is for now hypothetical hours index for Germany in the pandemic quarter, if we assume MCS is representative
gen male_index_mcs=hours_int_ext_male/sc_m_germany if country=="Germany" & year==2020 & q==2
gen female_index_mcs=hours_int_ext_female/sc_f_germany if country=="Germany" & year==2020 & q==2
gen all_index_mcs=hours_int_ext/sc_t_germany if country=="Germany" & year==2020 & q==2

***Now feed in numbers from IAB "volume of work"
gen volume_work=.
replace volume_work=15794.8414062388 if country=="Germany" & year==2019 & q==4 //IAB
replace volume_work=15717.3545717108 if country=="Germany" & year==2020 & q==1 //IAB
replace volume_work=13437.0770712855 if country=="Germany" & year==2020 & q==2 //IAB


****Scale them with the last data point from Eurostat hour index
gen scale_volume=volume_work/all_index if country=="Germany" & year==2019 & q==4
bysort country: egen sc_vol_germany=mean(scale_volume)

***convert them into comparable numbers with hour index. Note that all_index is our main variable which is filled by IAB data.
replace all_index=volume_work/sc_vol_germany if country=="Germany" & year==2020 & q==1
replace all_index=volume_work/sc_vol_germany if country=="Germany" & year==2020 & q==2


*Now we have to calculate the change in overall hours according to IAB and MCS, and scale MCS gender break accordingly. 
gen all_ger_19=all_index if country=="Germany" & year==2019 & q==4
bysort country:egen all_ger_19_=mean(all_ger_19)
gen all_ger_20=all_index if country=="Germany" & year==2020 & q==2
bysort country:egen all_ger_20_=mean(all_ger_20)

gen change_iab=log(all_ger_20_)-log(all_ger_19_)

gen all_ger_19_mcs=all_index if country=="Germany" & year==2019 & q==4
bysort country:egen all_ger_19_mcs_=mean(all_ger_19_mcs)
gen all_ger_20_mcs=all_index_mcs if country=="Germany" & year==2020 & q==2
bysort country:egen all_ger_20_mcs_=mean(all_ger_20_mcs)

gen change_mcs=log(all_ger_20_mcs_)-log(all_ger_19_mcs_)

gen change_scale=change_iab/change_mcs //this is our correction scale to make the overall change comparable and correct genders as well. 

*Now calculate the change in male and female hours in MCS
gen male_ger_19_mcs=male_index if country=="Germany" & year==2019 & q==4
bysort country:egen male_ger_19_mcs_=mean(male_ger_19_mcs)
gen male_ger_20_mcs=male_index_mcs if country=="Germany" & year==2020 & q==2
bysort country:egen male_ger_20_mcs_=mean(male_ger_20_mcs)

gen change_male_mcs=log(male_ger_20_mcs_)-log(male_ger_19_mcs_)

gen female_ger_19_mcs=female_index if country=="Germany" & year==2019 & q==4
bysort country:egen female_ger_19_mcs_=mean(female_ger_19_mcs)
gen female_ger_20_mcs=female_index_mcs if country=="Germany" & year==2020 & q==2
bysort country:egen female_ger_20_mcs_=mean(female_ger_20_mcs)

gen change_female_mcs=log(female_ger_20_mcs_)-log(female_ger_19_mcs_)


*******Here we correct the change by scaling it with our correction scale calculate above. 
replace change_male_mcs=change_male_mcs*change_scale
replace change_female_mcs=change_female_mcs*change_scale


***Now we have to fill in the male_index and female_index so that the change between 2019q4 and 2020q2 will be as calculated above
gen male_index_ger=male_index if country=="Germany" & year==2019 & q==4
bysort country: egen male_index_ger_=mean(male_index_ger)
gen female_index_ger=female_index if country=="Germany" & year==2019 & q==4
bysort country: egen female_index_ger_=mean(female_index_ger)

gen male_pandem_ger=exp(log(male_index_ger_)+change_male_mcs)
gen female_pandem_ger=exp(log(female_index_ger_)+change_female_mcs)

replace male_index=male_pandem_ger if country=="Germany" & year==2020 & q==2
replace female_index=female_pandem_ger if country=="Germany" & year==2020 & q==2

*################################***End of Germany Data Input***###############################################





label variable all_index hours_index_20_64_seas_adjusted
label variable male_index hours_index_20_64_male_seas_adjusted
label variable female_index hours_index_20_64_female_seas_adjusted
label variable all_emp total_employment_20_64_seas_adjusted
label variable male_emp male_employment_20_64_seas_adjusted
label variable female_emp female_employment_20_64_seas_adjusted
label variable gdp_sa realgdp_seas_adjusted
label variable gdppercap gdppercap_seas_adjusted


keep all_index male_index female_index all_emp male_emp female_emp gdp_sa year q yq country gdppercap
encode country, gen(c)
tsset c yq
save "${procdata}/hour_emp_gdp_quarter.dta", replace
