/* #############################################################################
Hours output for Covid impact in cross-country analysis
############################################################################# */

/*
Proxy the effect of the recession on men and women by using hours in 
- pre-Covid: July 2018
- during-Covid: 17-23 April, May 22-28, May 29-June 4, June 5-11, June 12-18, June 19-25
*/

clear

* Directories *
cd "${git_workdir}"

* Load updated dataset
use "${local_data_encryp}/Germany_clean_paneldata_2064.dta", clear



********************************************************************************
* weighted hours from MCS (reflecting Q2/2020)  *
*************************************************


** uncodnitional average hours worked
sum raw_hours [aw=wi_rake] if Woche == 5, de
gen avhrs_Apr = r(mean)

sum raw_hours [aw=wi_rake] if Woche == 10 | Woche == 11, de
gen avhrs_May = r(mean)

sum raw_hours [aw=wi_rake] if Woche == 12 | Woche == 13 | Woche == 14, de
gen avhrs_Jun = r(mean)

gen avhrs_Q2 = (avhrs_Apr + avhrs_May + avhrs_Jun)/3

di("average hours worked in Q2")
di(avhrs_Q2)


** men's average hours worked
sum raw_hours [aw=wi_rake] if sex == 1 & Woche == 5, de
gen avhrs_Apr_men = r(mean)

sum raw_hours [aw=wi_rake] if sex == 1 & (Woche == 10 | Woche == 11), de
gen avhrs_May_men = r(mean)

sum raw_hours [aw=wi_rake] if sex == 1 & (Woche == 12 | Woche == 13 | Woche == 14), de
gen avhrs_Jun_men = r(mean)

gen avhrs_Q2_men = (avhrs_Apr_men + avhrs_May_men + avhrs_Jun_men)/3

di("average hours worked by men in Q2")
di(avhrs_Q2_men)


** women's average hours worked
sum raw_hours [aw=wi_rake] if sex == 2 & Woche == 5, de
gen avhrs_Apr_women = r(mean)

sum raw_hours [aw=wi_rake] if sex == 2 & (Woche == 10 | Woche == 11), de
gen avhrs_May_women = r(mean)

sum raw_hours [aw=wi_rake] if sex == 2 & (Woche == 12 | Woche == 13 | Woche == 14), de
gen avhrs_Jun_women = r(mean)

gen avhrs_Q2_women = (avhrs_Apr_women + avhrs_May_women + avhrs_Jun_women)/3

di("average hours worked by women in Q2")
di(avhrs_Q2_women)


********************** Display ********************

di("average hours worked in Q2")
di(avhrs_Q2)

di("average hours worked by men in Q2")
di(avhrs_Q2_men)

di("average hours worked by women in Q2")
di(avhrs_Q2_women)


drop avhrs_Q2 avhrs_Q2_men avhrs_Q2_women

drop avhrs_Apr_women avhrs_May_women avhrs_Jun_women

drop avhrs_Apr_men avhrs_May_men avhrs_Jun_men

drop avhrs_Apr avhrs_May avhrs_Jun




********************************************************************************
* unweighted hours from MCS (reflecting Q2/2020)  *
***************************************************


** uncodnitional average hours worked
sum raw_hours if Woche == 5, de
gen avhrs_Apr = r(mean)

sum raw_hours if (Woche == 10 | Woche == 11), de
gen avhrs_May = r(mean)

sum raw_hours if (Woche == 12 | Woche == 13 | Woche == 14), de
gen avhrs_Jun = r(mean)

gen avhrs_Q2 = (avhrs_Apr + avhrs_May + avhrs_Jun)/3

di("average hours worked in Q2")
di(avhrs_Q2)


** men's average hours worked
sum raw_hours if sex == 1 & Woche == 5, de
gen avhrs_Apr_men = r(mean)

sum raw_hours if sex == 1 & (Woche == 10 | Woche == 11), de
gen avhrs_May_men = r(mean)

sum raw_hours if sex == 1 & (Woche == 12 | Woche == 13 | Woche == 14), de
gen avhrs_Jun_men = r(mean)

gen avhrs_Q2_men = (avhrs_Apr_men + avhrs_May_men + avhrs_Jun_men)/3

di("average hours worked by men in Q2")
di(avhrs_Q2_men)


** women's average hours worked
sum raw_hours if sex == 2 & Woche == 5, de
gen avhrs_Apr_women = r(mean)

sum raw_hours if sex == 2 & (Woche == 10 | Woche == 11), de
gen avhrs_May_women = r(mean)

sum raw_hours if sex == 2 & (Woche == 12 | Woche == 13 | Woche == 14), de
gen avhrs_Jun_women = r(mean)

gen avhrs_Q2_women = (avhrs_Apr_women + avhrs_May_women + avhrs_Jun_women)/3

di("average hours worked by women in Q2")
di(avhrs_Q2_women)


********************** Display ********************

di("average unweighted hours worked in Q2")
di(avhrs_Q2)

di("average unweighted hours worked by men in Q2")
di(avhrs_Q2_men)

di("average unweighted hours worked by women in Q2")
di(avhrs_Q2_women)



drop avhrs_Q2 avhrs_Q2_men avhrs_Q2_women

drop avhrs_Apr_women avhrs_May_women avhrs_Jun_women

drop avhrs_Apr_men avhrs_May_men avhrs_Jun_men

drop avhrs_Apr avhrs_May avhrs_Jun





********************************************************************************
* unweighted hours from July 2018  *
************************************


** women's average hours worked in July 2018
sum raw_hours if year == 2018 & month == 7, de
gen avhrs_Jul2018 = r(mean)

di("average hours worked by women in July 2018")
di(avhrs_Jul2018)


** men's average hours worked
sum raw_hours if sex == 1 & year == 2018 & month == 7, de
gen avhrs_Jul2018_men = r(mean)

di("average hours worked by men in Q2")
di(avhrs_Jul2018_men)


** women's average hours worked in July 2018
sum raw_hours if sex == 2 & year == 2018 & month == 7, de
gen avhrs_Jul2018_women = r(mean)

di("average hours worked by women in July 2018")
di(avhrs_Jul2018_women)





********************** Display ********************

di("average hours worked by women in July 2018")
di(avhrs_Jul2018)

di("average hours worked by men in Q2")
di(avhrs_Jul2018_men)

di("average hours worked by women in July 2018")
di(avhrs_Jul2018_women)



drop avhrs_Jul2018 avhrs_Jul2018_men avhrs_Jul2018_women








********************************************************************************
* unweighted intensive margin hours from MCS (reflecting Q2/2020)  *
********************************************************************


** uncodnitional average hours worked
sum raw_hours if broad_emp == 1 & Woche == 5, de
gen avhrs_Apr = r(mean)

sum raw_hours if broad_emp == 1 & (Woche == 10 | Woche == 11), de
gen avhrs_May = r(mean)

sum raw_hours if broad_emp == 1 & (Woche == 12 | Woche == 13 | Woche == 14), de
gen avhrs_Jun = r(mean)

gen avhrs_Q2 = (avhrs_Apr + avhrs_May + avhrs_Jun)/3

di("average hours worked in Q2")
di(avhrs_Q2)


** men's average hours worked
sum raw_hours if broad_emp == 1 & sex == 1 & Woche == 5, de
gen avhrs_Apr_men = r(mean)

sum raw_hours if broad_emp == 1 & sex == 1 & (Woche == 10 | Woche == 11), de
gen avhrs_May_men = r(mean)

sum raw_hours if broad_emp == 1 & sex == 1 & (Woche == 12 | Woche == 13 | Woche == 14), de
gen avhrs_Jun_men = r(mean)

gen avhrs_Q2_men = (avhrs_Apr_men + avhrs_May_men + avhrs_Jun_men)/3

di("average hours worked by men in Q2")
di(avhrs_Q2_men)


** women's average hours worked
sum raw_hours if broad_emp == 1 & sex == 2 & Woche == 5, de
gen avhrs_Apr_women = r(mean)

sum raw_hours if broad_emp == 1 & sex == 2 & (Woche == 10 | Woche == 11), de
gen avhrs_May_women = r(mean)

sum raw_hours if broad_emp == 1 & sex == 2 & (Woche == 12 | Woche == 13 | Woche == 14), de
gen avhrs_Jun_women = r(mean)

gen avhrs_Q2_women = (avhrs_Apr_women + avhrs_May_women + avhrs_Jun_women)/3

di("average hours worked by women in Q2")
di(avhrs_Q2_women)


********************** Display ********************

di("average unweighted hours worked in Q2")
di(avhrs_Q2)

di("average unweighted hours worked by men in Q2")
di(avhrs_Q2_men)

di("average unweighted hours worked by women in Q2")
di(avhrs_Q2_women)



drop avhrs_Q2 avhrs_Q2_men avhrs_Q2_women

drop avhrs_Apr_women avhrs_May_women avhrs_Jun_women

drop avhrs_Apr_men avhrs_May_men avhrs_Jun_men

drop avhrs_Apr avhrs_May avhrs_Jun





********************************************************************************
* unweighted intensive margin hours from July 2018  *
*****************************************************


** women's average hours worked in July 2018
sum raw_hours if broad_emp == 1 & year == 2018 & month == 7, de
gen avhrs_Jul2018 = r(mean)

di("average hours worked by women in July 2018")
di(avhrs_Jul2018)


** men's average hours worked
sum raw_hours if broad_emp == 1 & sex == 1 & year == 2018 & month == 7, de
gen avhrs_Jul2018_men = r(mean)

di("average hours worked by men in Q2")
di(avhrs_Jul2018_men)


** women's average hours worked in July 2018
sum raw_hours if broad_emp == 1 & sex == 2 & year == 2018 & month == 7, de
gen avhrs_Jul2018_women = r(mean)

di("average hours worked by women in July 2018")
di(avhrs_Jul2018_women)





********************** Display ********************

di("average hours worked by women in July 2018")
di(avhrs_Jul2018)

di("average hours worked by men in Q2")
di(avhrs_Jul2018_men)

di("average hours worked by women in July 2018")
di(avhrs_Jul2018_women)









