/* #############################################################################
Master file for Germany GIP-MCS code
############################################################################# */

// Code written by David Koll, koll@uni-mannheim.de, final version: June 2021, gitlab: david.dk

clear all

cls
set maxvar 20000
set matsize 10000
set emptycells drop


/* -----------------------------------------------------------------------------
Define preliminaries and set paths:
----------------------------------------------------------------------------- */

// Setting paths
// needs to contain raw German Internet Panel (GIP) and Mannheim Corona Study (MCS) data
global raw_GIP_data " xxx "

global raw_MCS_data " xxx "
* GIP_MSC_long_V0.dta

// local encrypted temp data
global local_data_encryp " put your local temp folder path here "

// set output folder
global out_dir " xxx "

// set git working directory - directory which contains the codes 
global git_workdir " xxx "

cap log close

/* -----------------------------------------------------------------------------
Data preparation: (Load data, clean data and create variables)
----------------------------------------------------------------------------- */

// Loading GIP data:
do "${git_workdir}/data_load_GIP49.do"

do "${git_workdir}/data_load_GIP47.do"

do "${git_workdir}/data_load_GIP45.do"

do "${git_workdir}/data_load_GIP43.do"

do "${git_workdir}/data_load_GIP39.do"

do "${git_workdir}/data_load_GIP37.do"

do "${git_workdir}/data_load_GIP36.do"


// Loading MCS data:
do "${git_workdir}/data_load_MCS.do"


// Create clean panel data set & panel data for hours calculation for section 2:
do "${git_workdir}/data_prep.do"




/* --------------------------------------------------------------------------------
Regression analyses - General impact and effect on gender gaps incl heterogeneity
-------------------------------------------------------------------------------- */

global samp_yr 2019 // sample year for employment estimation. Note: hours estimation is fixed

do "${git_workdir}/reg_aggregate.do" // aggregate employment and hours effect: Table 7a and 8a

do "${git_workdir}/reg_main.do" // main gender results in Table 7 and 8 

do "${git_workdir}/reg_EducRace.do" // heterogeneity of gender results: education & race/migration in Table 11 - 14 (plus Appendix tables A3 - A6) 

do "${git_workdir}/reg_SingleMothers.do" // single versus cohabiting mothers: Table 15



/* -----------------------------------------------------------------------------
Descriptives
- Appendix table
----------------------------------------------------------------------------- */

do "${git_workdir}/AppTableDescriptives.do" // Appendix Table C8



/* -----------------------------------------------------------------------------
Hours output for Covid impact in cross-country analysis
----------------------------------------------------------------------------- */

do "${git_workdir}/hours_crosscountry.do" // Input for Section 2


