/* #############################################################################
Regression setup: Education & Migration background
############################################################################# */


/*
1) Education setup: (for actual hours & employment)
- follows the main setup
- additionally interacts the coeficients of interest with a college dummy

2) Migration background:
- follows the main setup
- additionally interacts the coeficients of interest with a migration dummy

*/


* Preliminaries
clear

* Directories *
cd "${git_workdir}"

* Log File
log using "${out_dir}/Germany_DiD_EducRace.log", replace

* Load updated dataset
use "${local_data_encryp}/Germany_clean_paneldata.dta", clear



********************************************************************************
* Regressions: Education Levels *
*********************************

// SPEC 3A: Hours Education Regressions
***************************************

est clear 

preserve


* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


* Population
 reg hours Dt##ib1.sex#ib0.college                                      i.birth_year_cat i.simp_migration i.educ i.married,  robust 
est store bench  
matrix table_bench = r(table) //store reg results


 reg hours Dt##ib1.sex#ib0.college     Dt##i.work_type                    i.birth_year_cat i.simp_migration i.educ i.married,  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours Dt##ib1.sex#ib0.child_grp#ib0.college                          i.birth_year_cat i.simp_migration i.educ i.married,  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours Dt##ib1.sex#ib0.child_grp#ib0.college   Dt##i.work_type      i.birth_year_cat i.simp_migration i.educ i.married,  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/Germany_DiD.xlsx" , sheet("Table 12") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop Low Skill (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop High Skill (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids Low Skill  (bench)"
putexcel D2=table_kid[1,29]   
putexcel D3=table_kid[2,29] 
putexcel D4=table_kid[4,29] 

putexcel E1 =  "No Kids High Skill  (bench)"
putexcel E2=table_kid[1,30]   
putexcel E3=table_kid[2,30] 
putexcel E4=table_kid[4,30] 


putexcel F1 =  "Kids < 16 Low Skill  (bench)"
putexcel F2=table_kid[1,31]   
putexcel F3=table_kid[2,31] 
putexcel F4=table_kid[4,31] 

putexcel G1 =  "Kids < 16 High Skill  (bench)"
putexcel G2=table_kid[1,32]   
putexcel G3=table_kid[2,32] 
putexcel G4=table_kid[4,32] 


//...and with occ controls
putexcel H1 =  "Pop Low Skill (work type)"
putexcel H2=table_bench_occ[1,15] 
putexcel H3=table_bench_occ[2,15] 
putexcel H4=table_bench_occ[4,15] 

putexcel I1 =  "Pop High Skill (work type)"
putexcel I2=table_bench_occ[1,16] 
putexcel I3=table_bench_occ[2,16] 
putexcel I4=table_bench_occ[4,16] 


putexcel J1 =  "No Kids Low Skill  (work type)"
putexcel J2=table_kid_occ[1,29]   
putexcel J3=table_kid_occ[2,29] 
putexcel J4=table_kid_occ[4,29] 

putexcel K1 =  "No Kids High Skill  (work type)"
putexcel K2=table_kid_occ[1,30]   
putexcel K3=table_kid_occ[2,30] 
putexcel K4=table_kid_occ[4,30] 


putexcel L1 =  "Kids < 16 Low Skill  (work type)"
putexcel L2=table_kid_occ[1,31]   
putexcel L3=table_kid_occ[2,31] 
putexcel L4=table_kid_occ[4,31] 

putexcel M1 =  "Kids < 16 High Skill  (work type)"
putexcel M2=table_kid_occ[1,32]   
putexcel M3=table_kid_occ[2,32] 
putexcel M4=table_kid_occ[4,32] 




// SPEC 3B: Employment Education Regressions
********************************************

// **unweighted** regression
* no time effects (no quarter FE, no summer education dummies, no gender specific linear trends)
est clear 

preserve

* Time Sample
keep if year>=$samp_yr

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.

* Population
reg broad_emp Dt##ib1.sex#ib0.college                                      i.birth_year_cat i.simp_migration i.educ i.married,  robust 
est store bench  
matrix table_bench = r(table) //store reg results


reg broad_emp Dt##ib1.sex#ib0.college   Dt##i.work_type                    i.birth_year_cat i.simp_migration i.educ i.married ,  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
reg broad_emp Dt##ib1.sex#ib0.child_grp#ib0.college                        i.birth_year_cat i.simp_migration i.educ i.married ,  robust 
est store kid
matrix table_kid = r(table) //store reg results


reg broad_emp Dt##ib1.sex#ib0.child_grp#ib0.college   Dt##i.work_type      i.birth_year_cat i.simp_migration i.educ i.married ,  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 



* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/Germany_DiD.xlsx" , sheet("Table 11") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop Low Skill (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop High Skill (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids Low Skill  (bench)"
putexcel D2=table_kid[1,29]   
putexcel D3=table_kid[2,29] 
putexcel D4=table_kid[4,29] 

putexcel E1 =  "No Kids High Skill  (bench)"
putexcel E2=table_kid[1,30]   
putexcel E3=table_kid[2,30] 
putexcel E4=table_kid[4,30] 


putexcel F1 =  "Kids < 16 Low Skill  (bench)"
putexcel F2=table_kid[1,31]   
putexcel F3=table_kid[2,31] 
putexcel F4=table_kid[4,31] 

putexcel G1 =  "Kids < 16 High Skill  (bench)"
putexcel G2=table_kid[1,32]   
putexcel G3=table_kid[2,32] 
putexcel G4=table_kid[4,32] 


//...and with occ controls
putexcel H1 =  "Pop Low Skill (work type)"
putexcel H2=table_bench_occ[1,15] 
putexcel H3=table_bench_occ[2,15] 
putexcel H4=table_bench_occ[4,15] 

putexcel I1 =  "Pop High Skill (work type)"
putexcel I2=table_bench_occ[1,16] 
putexcel I3=table_bench_occ[2,16] 
putexcel I4=table_bench_occ[4,16] 


putexcel J1 =  "No Kids Low Skill  (work type)"
putexcel J2=table_kid_occ[1,29]   
putexcel J3=table_kid_occ[2,29] 
putexcel J4=table_kid_occ[4,29] 

putexcel K1 =  "No Kids High Skill  (work type)"
putexcel K2=table_kid_occ[1,30]   
putexcel K3=table_kid_occ[2,30] 
putexcel K4=table_kid_occ[4,30] 


putexcel L1 =  "Kids < 16 Low Skill  (work type)"
putexcel L2=table_kid_occ[1,31]   
putexcel L3=table_kid_occ[2,31] 
putexcel L4=table_kid_occ[4,31] 

putexcel M1 =  "Kids < 16 High Skill  (work type)"
putexcel M2=table_kid_occ[1,32]   
putexcel M3=table_kid_occ[2,32] 
putexcel M4=table_kid_occ[4,32] 





********************************************************************************
* Regressions: Education Levels *
*********************************

// SPEC 4A: Hours gender gap and broad race (white v non-white)
***************************************************************

est clear 

preserve


* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


* Population
 reg hours Dt##ib1.sex#i.simp_migration                                      i.birth_year_cat i.educ i.married,  robust 
est store bench  
matrix table_bench = r(table) //store reg results


 reg hours Dt##ib1.sex#i.simp_migration     Dt##i.work_type                    i.birth_year_cat i.educ i.married,  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours Dt##ib1.sex#ib0.child_grp#i.simp_migration                          i.birth_year_cat i.educ i.married,  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours Dt##ib1.sex#ib0.child_grp#i.simp_migration   Dt##i.work_type      i.birth_year_cat i.educ i.married,  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/Germany_DiD.xlsx" , sheet("Table 14") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop White (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop Non-white (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids White  (bench)"
putexcel D2=table_kid[1,29]   
putexcel D3=table_kid[2,29] 
putexcel D4=table_kid[4,29] 

putexcel E1 =  "No Kids Non-white  (bench)"
putexcel E2=table_kid[1,30]   
putexcel E3=table_kid[2,30] 
putexcel E4=table_kid[4,30] 


putexcel F1 =  "Kids < 16 White  (bench)"
putexcel F2=table_kid[1,31]   
putexcel F3=table_kid[2,31] 
putexcel F4=table_kid[4,31] 

putexcel G1 =  "Kids < 16 Non-white  (bench)"
putexcel G2=table_kid[1,32]   
putexcel G3=table_kid[2,32] 
putexcel G4=table_kid[4,32] 


//...and with occ controls
putexcel H1 =  "Pop White (work type)"
putexcel H2=table_bench_occ[1,15] 
putexcel H3=table_bench_occ[2,15] 
putexcel H4=table_bench_occ[4,15] 

putexcel I1 =  "Pop Non-white (work type)"
putexcel I2=table_bench_occ[1,16] 
putexcel I3=table_bench_occ[2,16] 
putexcel I4=table_bench_occ[4,16] 


putexcel J1 =  "No Kids White  (work type)"
putexcel J2=table_kid_occ[1,29]   
putexcel J3=table_kid_occ[2,29] 
putexcel J4=table_kid_occ[4,29] 

putexcel K1 =  "No Kids Non-white  (work type)"
putexcel K2=table_kid_occ[1,30]   
putexcel K3=table_kid_occ[2,30] 
putexcel K4=table_kid_occ[4,30] 


putexcel L1 =  "Kids < 16 White  (work type)"
putexcel L2=table_kid_occ[1,31]   
putexcel L3=table_kid_occ[2,31] 
putexcel L4=table_kid_occ[4,31] 

putexcel M1 =  "Kids < 16 Non-white  (work type)"
putexcel M2=table_kid_occ[1,32]   
putexcel M3=table_kid_occ[2,32] 
putexcel M4=table_kid_occ[4,32] 




// SPEC 4B: Employment gender gap and broad race (white v non-white)
********************************************************************

// **unweighted** regression
* no time effects (no quarter FE, no summer education dummies, no gender specific linear trends)
est clear 

preserve

* Time Sample
keep if year>=$samp_yr

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.

* Population
reg broad_emp Dt##ib1.sex#i.simp_migration                                      i.birth_year_cat i.educ i.married,  robust 
est store bench  
matrix table_bench = r(table) //store reg results


reg broad_emp Dt##ib1.sex#i.simp_migration   Dt##i.work_type                    i.birth_year_cat i.educ i.married ,  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
reg broad_emp Dt##ib1.sex#ib0.child_grp#i.simp_migration                        i.birth_year_cat i.educ i.married ,  robust 
est store kid
matrix table_kid = r(table) //store reg results


reg broad_emp Dt##ib1.sex#ib0.child_grp#i.simp_migration   Dt##i.work_type      i.birth_year_cat i.educ i.married ,  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 



* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/Germany_DiD.xlsx" , sheet("Table 13") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop White (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop Non-white (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids White  (bench)"
putexcel D2=table_kid[1,29]   
putexcel D3=table_kid[2,29] 
putexcel D4=table_kid[4,29] 

putexcel E1 =  "No Kids Non-white  (bench)"
putexcel E2=table_kid[1,30]   
putexcel E3=table_kid[2,30] 
putexcel E4=table_kid[4,30] 


putexcel F1 =  "Kids < 16 White  (bench)"
putexcel F2=table_kid[1,31]   
putexcel F3=table_kid[2,31] 
putexcel F4=table_kid[4,31] 

putexcel G1 =  "Kids < 16 Non-white  (bench)"
putexcel G2=table_kid[1,32]   
putexcel G3=table_kid[2,32] 
putexcel G4=table_kid[4,32] 


//...and with occ controls
putexcel H1 =  "Pop White (work type)"
putexcel H2=table_bench_occ[1,15] 
putexcel H3=table_bench_occ[2,15] 
putexcel H4=table_bench_occ[4,15] 

putexcel I1 =  "Pop Non-white (work type)"
putexcel I2=table_bench_occ[1,16] 
putexcel I3=table_bench_occ[2,16] 
putexcel I4=table_bench_occ[4,16] 


putexcel J1 =  "No Kids White  (work type)"
putexcel J2=table_kid_occ[1,29]   
putexcel J3=table_kid_occ[2,29] 
putexcel J4=table_kid_occ[4,29] 

putexcel K1 =  "No Kids Non-white  (work type)"
putexcel K2=table_kid_occ[1,30]   
putexcel K3=table_kid_occ[2,30] 
putexcel K4=table_kid_occ[4,30] 


putexcel L1 =  "Kids < 16 White  (work type)"
putexcel L2=table_kid_occ[1,31]   
putexcel L3=table_kid_occ[2,31] 
putexcel L4=table_kid_occ[4,31] 

putexcel M1 =  "Kids < 16 Non-white  (work type)"
putexcel M2=table_kid_occ[1,32]   
putexcel M3=table_kid_occ[2,32] 
putexcel M4=table_kid_occ[4,32] 






********************************************************************************
********************************************************************************

log close

