/* #############################################################################
Regression setup: Education, whites & single mothers
############################################################################# */


/*
1) Education setup: (for actual hours & employment)
- follows the main setup
- additionally interacts the coeficients of interest with a college dummy

2) Race setup
- whites versus non-whites
*/

* Preliminaries
clear


* Directories *
cd "${local_workdir}"


* Log File
log using "${out_dir}/UK_DiD_EducRaceSingle.log", replace

* Load saved dataset
use "${local_workdir}/UK_cleaned_data.dta", clear



********************************************************************************
* Regressions: Education Levels *
*********************************

// SPEC 3A: Hours Education Regressions
***************************************
preserve

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


* Population
 reg hours_lwk Dt##ib1.sex#ib0.college c.time_var_reg#ib1.sex                                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.college  c.time_var_reg#ib1.sex  Dt##i.work_type                     i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var_reg#ib1.sex                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var_reg#ib1.sex  Dt##i.work_type        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("Table 12") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop Low Skill (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop High Skill (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids Low Skill  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids High Skill  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids Low Skill  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids High Skill  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids Low Skill  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids High Skill  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 



//...and with occ controls

putexcel J1 =  "Pop Low Skill (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop High Skill (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids Low Skill  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids High Skill  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids Low Skill  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids High Skill  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids Low Skill  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids High Skill  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 




// SPEC 3B: Employment Education Regressions
********************************************
preserve


* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


* Population
 reg broad_emp Dt##ib1.sex#ib0.college c.time_var_reg#ib1.sex                                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

 reg broad_emp Dt##ib1.sex#ib0.college  c.time_var_reg#ib1.sex  Dt##i.work_type                     i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg broad_emp Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var_reg#ib1.sex                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg broad_emp Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var_reg#ib1.sex  Dt##i.work_type        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("Table 11") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop Low Skill (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop High Skill (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids Low Skill  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids High Skill  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids Low Skill  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids High Skill  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids Low Skill  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids High Skill  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 


//...and with occ controls
putexcel J1 =  "Pop Low Skill (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop High Skill (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids Low Skill  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids High Skill  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids Low Skill  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids High Skill  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids Low Skill  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids High Skill  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 




********************************************************************************
* Regressions: Broad Race (white v non-white) *
***********************************************

// SPEC 4A: Hours gender gap and broad race (white v non-white)
preserve

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


* Population
  reg hours_lwk Dt##ib1.sex#i.simp_race c.time_var_reg#ib1.sex                                      i.sum_edu i.Qt i.age_grp  i.simp_educ [pweight=PWT18],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

  reg hours_lwk Dt##ib1.sex#i.simp_race  c.time_var_reg#ib1.sex  Dt##i.work_type                    i.sum_edu i.Qt i.age_grp  i.simp_educ [pweight=PWT18],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours_lwk Dt##ib1.sex#ib0.child_grp#i.simp_race  c.time_var_reg#ib1.sex                       i.sum_edu i.Qt i.age_grp  i.simp_educ [pweight=PWT18],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.child_grp#i.simp_race  c.time_var_reg#ib1.sex  Dt##i.work_type      i.sum_edu i.Qt i.age_grp  i.simp_educ [pweight=PWT18],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results


restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("Table 14") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop White (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop Non-white (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids White  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids Non-white  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids White  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids Non-white  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids White  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids Non-white  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 


//...and with occ controls
putexcel J1 =  "Pop White (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop Non-white (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids White  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids Non-white  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids White  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids Non-white  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids White  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids Non-white  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 



// SPEC 4B: Employment gender gap and broad race (white v non-white)
preserve

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


* Population
  reg broad_emp Dt##ib1.sex#i.simp_race c.time_var_reg#ib1.sex                                      i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pweight=PWT18],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

  reg broad_emp Dt##ib1.sex#i.simp_race  c.time_var_reg#ib1.sex  Dt##i.work_type                    i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pweight=PWT18],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg broad_emp Dt##ib1.sex#ib0.child_grp#i.simp_race  c.time_var_reg#ib1.sex                       i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pweight=PWT18],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg broad_emp Dt##ib1.sex#ib0.child_grp#i.simp_race  c.time_var_reg#ib1.sex  Dt##i.work_type      i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pweight=PWT18],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("Table 13") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop White (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop Non-white (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids White  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids Non-white  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids White  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids Non-white  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids White  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids Non-white  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 


//...and with occ controls
putexcel J1 =  "Pop White (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop Non-white (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids White  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids Non-white  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids White  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids Non-white  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids White  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids Non-white  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 



********************************************************************************
********************************************************************************
log close






