/* #############################################################################
Main regression setup - for aggregate employment and hour effect
############################################################################# */

/*
main setup: (for actual hours, employment and usual hours)
- quarterly seasonality dummies
- dummy for education sector workers in summer time
*/

* Preliminaries
clear


* Directories *
cd "${local_workdir}"


* Log File
log using "${out_dir}/UK_DiD_aggregate.log", replace

* Load saved dataset
use "${local_workdir}/UK_cleaned_data.dta", clear




********************************************************************************
* Regression: Hours Last Week *
********************************


// includes summer education dummies and quarter FE
est clear 

preserve

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


* Overall change, without controls (except quarter and education dummies)
reg hours_lwk Dt                                     i.sum_edu i.Qt  [pweight=PWT18],  robust 
est store spec1_nocontrols  
matrix table_spec1_nocontrols = r(table) //store reg results


* Overall change, with benchmark controls (except gender specific time trend)
reg hours_lwk Dt                                     i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=PWT18],  robust 
est store spec1_controls  
matrix table_spec1_controls = r(table) //store reg results


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("Table 8a") modify  // replace first time around
putexcel A1 =  "Statistic:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Overall Hrs_lwk (no cont)"
putexcel B2=table_spec1_nocontrols[1,1] 
putexcel B3=table_spec1_nocontrols[2,1] 
putexcel B4=table_spec1_nocontrols[4,1] 

putexcel C1 =  "Overall Hrs_lwk (with cont)"
putexcel C2=table_spec1_controls[1,1] 
putexcel C3=table_spec1_controls[2,1] 
putexcel C4=table_spec1_controls[4,1] 

restore




********************************************************************************
* Regression: Broad employment *
********************************


// includes summer education dummies and quarter FE
est clear 

preserve

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.


* Overall change, without controls (except quarter and education dummies)
reg broad_emp Dt                                     i.sum_edu i.Qt  [pweight=PWT18],  robust 
est store spec2_nocontrols  
matrix table_spec2_nocontrols = r(table) //store reg results


* Overall change, with benchmark controls (except gender specific time trend)
reg broad_emp Dt                                     i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=PWT18],  robust 
est store spec2_controls  
matrix table_spec2_controls = r(table) //store reg results


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("Table 7a") modify  // replace first time around
putexcel A1 =  "Statistic:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Broad employment (no cont)"
putexcel B2=table_spec2_nocontrols[1,1] 
putexcel B3=table_spec2_nocontrols[2,1] 
putexcel B4=table_spec2_nocontrols[4,1] 

putexcel C1 =  "Broad employment (with cont)"
putexcel C2=table_spec2_controls[1,1] 
putexcel C3=table_spec2_controls[2,1] 
putexcel C4=table_spec2_controls[4,1] 

restore


log close

