/* #############################################################################
Main regression setup
############################################################################# */

/*
main setup: (for actual hours and employment)
- allow for linear gender specific time trends
- quarterly seasonality dummies
- dummy for education sector workers in summer time
- Interacting child_grp with the gender gap only (not the controls)
*/

* Preliminaries
clear


* Directories *
cd "${local_workdir}"


* Log File
log using "${out_dir}/UK_DiD_main.log", replace

* Load saved dataset
use "${local_workdir}/UK_cleaned_data.dta", clear




********************************************************************************
* Regressions: Hours Last Week *
********************************

// includes summer education dummies, interacted with detailed child groups, gender specific trends
est clear 

preserve

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.

* Population
reg hours_lwk Dt##ib1.sex c.time_var_reg#ib1.sex                                      i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=PWT18],  robust 
est store bench  
matrix table_bench = r(table) //store reg results


reg hours_lwk Dt##ib1.sex  c.time_var_reg#ib1.sex  Dt##i.work_type                    i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=PWT18],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
reg hours_lwk Dt##ib1.sex#ib0.child_grp  c.time_var_reg#ib1.sex                       i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=PWT18],  robust 
est store kid
matrix table_kid = r(table) //store reg results

reg hours_lwk Dt##ib1.sex#ib0.child_grp  c.time_var_reg#ib1.sex  Dt##i.work_type      i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=PWT18],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("Table 8b") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Population (bench)"
putexcel B2=table_bench[1,8] 
putexcel B3=table_bench[2,8] 
putexcel B4=table_bench[4,8] 

putexcel C1 =  "No Kids (bench)"
putexcel C2=table_kid[1,22]   
putexcel C3=table_kid[2,22] 
putexcel C4=table_kid[4,22] 

putexcel D1 =  "Small Kids (bench)"
putexcel D2=table_kid[1,23] 
putexcel D3=table_kid[2,23] 
putexcel D4=table_kid[4,23] 

putexcel E1 =  "School Kids (bench)"
putexcel E2=table_kid[1,24] 
putexcel E3=table_kid[2,24] 
putexcel E4=table_kid[4,24] 

//...and with occ controls

* Regression Results
putexcel F1 =  "Population (work type)"
putexcel F2=table_bench_occ[1,8] 
putexcel F3=table_bench_occ[2,8] 
putexcel F4=table_bench_occ[4,8] 

putexcel G1 =  "No Kids (work type)"
putexcel G2=table_kid_occ[1,22]   
putexcel G3=table_kid_occ[2,22] 
putexcel G4=table_kid_occ[4,22] 

putexcel H1 =  "Small Kids (work type)"
putexcel H2=table_kid_occ[1,23] 
putexcel H3=table_kid_occ[2,23] 
putexcel H4=table_kid_occ[4,23] 

putexcel I1 =  "School Kids (work type)"
putexcel I2=table_kid_occ[1,24] 
putexcel I3=table_kid_occ[2,24] 
putexcel I4=table_kid_occ[4,24] 



********************************************************************************
* Regressions: Broad Employment *
*********************************


// includes summer education dummies, interacted with detailed child groups, gender specific trends
est clear 

preserve

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.

* Population
reg broad_emp Dt##ib1.sex c.time_var_reg#ib1.sex                                      i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=PWT18],  robust 
est store bench  
matrix table_bench = r(table) //store reg results


reg broad_emp Dt##ib1.sex  c.time_var_reg#ib1.sex  Dt##i.work_type                    i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=PWT18],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
reg broad_emp Dt##ib1.sex#ib0.child_grp  c.time_var_reg#ib1.sex                       i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=PWT18],  robust 
est store kid
matrix table_kid = r(table) //store reg results


reg broad_emp Dt##ib1.sex#ib0.child_grp  c.time_var_reg#ib1.sex  Dt##i.work_type      i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pweight=PWT18],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("Table 7b") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Population (bench)"
putexcel B2=table_bench[1,8] 
putexcel B3=table_bench[2,8] 
putexcel B4=table_bench[4,8] 

putexcel C1 =  "No Kids (bench)"
putexcel C2=table_kid[1,22]   
putexcel C3=table_kid[2,22] 
putexcel C4=table_kid[4,22] 

putexcel D1 =  "Small Kids (bench)"
putexcel D2=table_kid[1,23] 
putexcel D3=table_kid[2,23] 
putexcel D4=table_kid[4,23] 

putexcel E1 =  "School Kids (bench)"
putexcel E2=table_kid[1,24] 
putexcel E3=table_kid[2,24] 
putexcel E4=table_kid[4,24] 

//...and with occ controls

* Regression Results
putexcel F1 =  "Population (work type)"
putexcel F2=table_bench_occ[1,8] 
putexcel F3=table_bench_occ[2,8] 
putexcel F4=table_bench_occ[4,8] 

putexcel G1 =  "No Kids (work type)"
putexcel G2=table_kid_occ[1,22]   
putexcel G3=table_kid_occ[2,22] 
putexcel G4=table_kid_occ[4,22] 

putexcel H1 =  "Small Kids (work type)"
putexcel H2=table_kid_occ[1,23] 
putexcel H3=table_kid_occ[2,23] 
putexcel H4=table_kid_occ[4,23] 

putexcel I1 =  "School Kids (work type)"
putexcel I2=table_kid_occ[1,24] 
putexcel I3=table_kid_occ[2,24] 
putexcel I4=table_kid_occ[4,24] 


********************************************************************************
********************************************************************************

log close

