/* #############################################################################
Master file for UK-LFS code
############################################################################# */

// Code written by David Koll, koll@uni-mannheim.de, final version: June 2021, gitlab: david.dk

clear all

cls
set maxvar 20000
set matsize 10000
set emptycells drop

/* --------------------------------------------------------------------------------
Define preliminaries and set paths:
-------------------------------------------------------------------------------- */

// Setting paths

// needs to contain raw QLS data
global raw_data " xxx "

// set local working directory (for temporary data files) and output folder
global local_workdir " xxx "
global out_dir " xxx "

// set directory of the replication codes - needs to contain replication codes
global git_workdir " xxx "

cap log close

/* --------------------------------------------------------------------------------
Data preparation: (Load data, clean data and create variables)
-------------------------------------------------------------------------------- */

do "${git_workdir}/QLFS_data_prep.do"


/* --------------------------------------------------------------------------------
Regression analyses - General impact and effect on gender gaps incl heterogeneity
-------------------------------------------------------------------------------- */

do "${git_workdir}/QLFS_reg_aggregate.do" // aggregate employment and hours effect

do "${git_workdir}/QLFS_reg_main.do" // main gender results in Table 7 and 8 

do "${git_workdir}/QLFS_reg_EducRace.do" // heterogeneity of gender results: education & race/migration in Table 11 - 14 (plus Appendix tables A3 - A6) 

do "${git_workdir}/QLFS_reg_SingleMothers.do" // single versus cohabiting mothers: Table 15

do "${git_workdir}/QLFS_reg_telecom.do" // gender results by telecommuting: Table 16 & 18



/* -----------------------------------------------------------------------------
Descriptives
- Appendix table
----------------------------------------------------------------------------- */

do "${git_workdir}/AppTableDescriptives.do" // Appendix Table C8

